@@ -17,13 +17,19 @@ class CliffWalk(Gridworld):
     **termination**: Entering The Cliff or reaching the goal.
     """
 
+    layout = """
+|            |
+|            |
+|            |
+|S          G|
+"""
+
     def __init__(self):
         self._cliff = frozenset((x, 0) for x in range(1, 11))
-        self._goal = (11, 0)
-        super().__init__(dims=(12, 4), starts={(0, 0)})
+        super().__init__(CliffWalk.layout)
 
     def _reward(self, state, action, next_state):
         return -100.0 if next_state in self._cliff else -1.0
 
     def _done(self, state, action, next_state):
-        return (next_state == self._goal) or (next_state in self._cliff)
+        return (next_state in self._goals) or (next_state in self._cliff)
