@@ -16,13 +16,20 @@ class DynaMaze(Gridworld):
     **termination**: Reaching the goal.
     """
 
+    layout = """
+|       XG|
+|  X    X |
+|S X    X |
+|  X      |
+|     X   |
+|         |
+"""
+
     def __init__(self):
-        blocks = frozenset({(2, 2), (2, 3), (2, 4), (5, 1), (7, 3), (7, 4), (7, 5)})
-        self._goal = (8, 5)
-        super().__init__(dims=(9, 6), starts={(0, 3)}, blocks=blocks)
+        super().__init__(DynaMaze.layout)
 
     def _reward(self, state, action, next_state):
-        return 1.0 if next_state == self._goal else 0.0
+        return 1.0 if next_state in self._goals else 0.0
 
     def _done(self, state, action, next_state):
-        return next_state == self._goal
+        return next_state in self._goals
