@@ -18,15 +18,25 @@ class FourRooms(NoisyGridworld):
     **termination**: Taking any action in the goal.
     """
 
+    layout = """
+|     X     |
+|     X     |
+|           |
+|     X     |
+|     X     |
+|X XXXX     |
+|     XXX XX|
+|     X     |
+|     X     |
+|           |
+|S    X     |
+"""
+
     def __init__(self):
-        blocks = frozenset({(5,0), (5,2), (5,3), (5,4), (5,5), (5,6), (5,7), (5,9), (5,10),
-                            (0,5), (2,5), (3,5), (4,5),
-                            (6,4), (7,4), (9,4), (10,4)})
-        self._goal = (10, 10)
-        super().__init__(dims=(11, 11), starts={(0, 0)}, blocks=blocks)
+        super().__init__(FourRooms.layout)
 
     def _reward(self, state, action, next_state):
         return 1.0 if self._done(state, action, next_state) else 0.0
 
     def _done(self, state, action, next_state):
-        return state == self._goal
+        return state in self._goals
